Wand_
~~~~~

Wand is a ``ctypes``-based simple `MagickWand API`_ binding for Python.
It doesn't cover all functionalities of MagickWand API currently.

You can install the package from PyPI_ by using ``pip`` or
``easy_install``::

    $ pip install Wand

Or would you like to enjoy with bleeding edge?  Check out the head
revision of the source code from the `GitHub repository`__::

    $ git clone git@github.com:StyleShare/wand.git
    $ cd wand/
    $ python setup.py install

.. _Wand: http://styleshare.github.com/wand/
.. _MagickWand API: http://www.imagemagick.org/script/magick-wand.php
.. _PyPI: http://pypi.python.org/pypi/Wand
__ https://github.com/StyleShare/wand
